@@ -23,10 +23,10 @@ class prebuilt_binary(build_ext.build_ext):
         for ext in self.extensions:
             fullname = self.get_ext_fullname(ext.name)
             filename = self.get_ext_filename(fullname)
-            if not os.path.exists(self.build_lib):
-                os.makedirs(self.build_lib)
-            dest_filename = os.path.join(self.build_lib,
-                                         os.path.basename(filename))
+            dest_filename = os.path.join(self.build_lib, filename)
+            dest_folder = os.path.dirname(dest_filename)
+            if not os.path.exists(dest_folder):
+                os.makedirs(dest_folder)
 
             copy_file(
                 ext.input_file, dest_filename, verbose=self.verbose,
